import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

import aws_cdk.aws_iam
import aws_cdk.aws_iot
import aws_cdk.aws_lambda
import aws_cdk.core
import aws_solutions_konstruk.core
import constructs

__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-solutions-konstruk/aws-iot-lambda", "0.8.1", __name__[0:-6], "aws-iot-lambda@0.8.1.jsii.tgz")

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
